==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Libs/C++/Include/CDPL/ConfGen/CFLMoleculeReader.hpp <==
/* 
 * CFLMoleculeReader.hpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of the class CDPL::ConfGen::CFLMoleculeReader.
 */

#ifndef CDPL_CONFGEN_CFLMOLECULEREADER_HPP
#define CDPL_CONFGEN_CFLMOLECULEREADER_HPP

#include <memory>

#include "CDPL/ConfGen/APIPrefix.hpp"
#include "CDPL/Util/StreamDataReader.hpp"


namespace CDPL
{

    namespace Chem
    {

        class Molecule;
    }

    namespace ConfGen
    {

        class CFLDataReader;

        /**
         * \brief A reader for molecule data in the native I/O format of the <em>CDPL</em>.
         */
        class CDPL_CONFGEN_API CFLMoleculeReader : public Util::StreamDataReader<Chem::Molecule, CFLMoleculeReader>
        {

          public:
            /**
             * \brief Constructs a \c %CFLMoleculeReader instance that will read the molecule data from the input
             *        stream \a is.
             * \param is The input stream to read from.
             */
            CFLMoleculeReader(std::istream& is);

            /**
             * \brief Destructor.
             */
            ~CFLMoleculeReader();

          private:
            friend class Util::StreamDataReader<Chem::Molecule, CFLMoleculeReader>;

            CFLMoleculeReader(const CFLMoleculeReader&);

            CFLMoleculeReader& operator=(const CFLMoleculeReader&);

            bool readData(std::istream&, Chem::Molecule&, bool overwrite);
            bool skipData(std::istream&);
            bool moreData(std::istream&);

            typedef std::unique_ptr<CFLDataReader> CFLDataReaderPtr;

            CFLDataReaderPtr reader;
        };
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_CFLMOLECULEREADER_HPP

==> CDPKit-1.2.0.dev1.tar.gz: CDPKit-1.2.0.dev1/Libs/C++/Include/CDPL/ConfGen/CFLMoleculeReader.hpp <==
/* 
 * CFLMoleculeReader.hpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of the class CDPL::ConfGen::CFLMoleculeReader.
 */

#ifndef CDPL_CONFGEN_CFLMOLECULEREADER_HPP
#define CDPL_CONFGEN_CFLMOLECULEREADER_HPP

#include <memory>

#include "CDPL/ConfGen/APIPrefix.hpp"
#include "CDPL/Util/StreamDataReader.hpp"


namespace CDPL
{

    namespace Chem
    {

        class Molecule;
    }

    namespace ConfGen
    {

        class CFLDataReader;

        /**
         * \brief A reader for molecule data in the native I/O format of the <em>CDPL</em>.
         */
        class CDPL_CONFGEN_API CFLMoleculeReader : public Util::StreamDataReader<Chem::Molecule, CFLMoleculeReader>
        {

          public:
            /**
             * \brief Constructs a \c %CFLMoleculeReader instance that will read the molecule data from the input
             *        stream \a is.
             * \param is The input stream to read from.
             */
            CFLMoleculeReader(std::istream& is);

            CFLMoleculeReader(const CFLMoleculeReader&) = delete;

            /**
             * \brief Destructor.
             */
            ~CFLMoleculeReader();

            CFLMoleculeReader& operator=(const CFLMoleculeReader&) = delete;

          private:
            friend class Util::StreamDataReader<Chem::Molecule, CFLMoleculeReader>;

            bool readData(std::istream&, Chem::Molecule&, bool overwrite);
            bool skipData(std::istream&);
            bool moreData(std::istream&);

            typedef std::unique_ptr<CFLDataReader> CFLDataReaderPtr;

            CFLDataReaderPtr reader;
        };
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_CFLMOLECULEREADER_HPP
